==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggwidgetprogressbar.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A generic ProgressBar class
//
#ifndef IGGWIDGETPROGRESSBAR_H
#define IGGWIDGETPROGRESSBAR_H


#include "iggwidget.h"


class ibgWidgetProgressBarSubject;


class iggWidgetProgressBar : public iggWidget
{

public:

	iggWidgetProgressBar(iggFrame *parent, bool unlaid = false);
	virtual ~iggWidgetProgressBar();

	void SetLabel(const iString &label);
	void SetProgress(int p);
	void Reset();

	void Abort();
	inline bool IsAborted() const { return mAborted; }

	inline ibgWidgetProgressBarSubject* GetSubject() const { return mSubject; } // needed for re-parenting

protected:

	virtual bool UpdateWidgetBody();
	virtual void OnSetProgress();

	ibgWidgetProgressBarSubject *mSubject;
	bool mAborted;
};

#endif // IGGWIDGETPROGRESSBAR_H

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/shells/generic/iggwidgetprogressbar.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A generic ProgressBar class
//
#ifndef IGGWIDGETPROGRESSBAR_H
#define IGGWIDGETPROGRESSBAR_H


#include "iggwidget.h"


class ibgWidgetProgressBarSubject;


class iggWidgetProgressBar : public iggWidget
{

public:

	iggWidgetProgressBar(iggFrame *parent, bool unlaid = false);
	virtual ~iggWidgetProgressBar();

	void SetLabel(const iString &label);
	void SetProgress(int p);
	void Reset();

	void Abort();
	inline bool IsAborted() const { return mAborted; }

	inline ibgWidgetProgressBarSubject* GetSubject() const { return mSubject; } // needed for re-parenting

protected:

	virtual void UpdateWidgetBody();
	virtual void OnSetProgress();

	ibgWidgetProgressBarSubject *mSubject;
	bool mAborted;
};

#endif // IGGWIDGETPROGRESSBAR_H
